# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'source/settings_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_settingsWindow(object):
    def setupUi(self, settingsWindow):
        settingsWindow.setObjectName("settingsWindow")
        settingsWindow.resize(675, 531)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(settingsWindow)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.scrollArea = QtWidgets.QScrollArea(settingsWindow)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 653, 509))
        self.scrollAreaWidgetContents.setMinimumSize(QtCore.QSize(600, 500))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setContentsMargins(-1, 0, -1, -1)
        self.gridLayout.setObjectName("gridLayout")
        self.labelKeystrokeSounds = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        font = QtGui.QFont()
        font.setPointSize(24)
        self.labelKeystrokeSounds.setFont(font)
        self.labelKeystrokeSounds.setObjectName("labelKeystrokeSounds")
        self.gridLayout.addWidget(self.labelKeystrokeSounds, 3, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem1, 2, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.buttonMainMenu = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonMainMenu.sizePolicy().hasHeightForWidth())
        self.buttonMainMenu.setSizePolicy(sizePolicy)
        self.buttonMainMenu.setMinimumSize(QtCore.QSize(0, 40))
        self.buttonMainMenu.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonMainMenu.setAutoDefault(False)
        self.buttonMainMenu.setDefault(True)
        self.buttonMainMenu.setObjectName("buttonMainMenu")
        self.horizontalLayout.addWidget(self.buttonMainMenu)
        self.buttonApply = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonApply.sizePolicy().hasHeightForWidth())
        self.buttonApply.setSizePolicy(sizePolicy)
        self.buttonApply.setMinimumSize(QtCore.QSize(0, 40))
        self.buttonApply.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonApply.setAutoDefault(True)
        self.buttonApply.setDefault(False)
        self.buttonApply.setObjectName("buttonApply")
        self.horizontalLayout.addWidget(self.buttonApply)
        self.gridLayout.addLayout(self.horizontalLayout, 8, 0, 1, 1)
        self.layoutKeystrokeSounds = QtWidgets.QHBoxLayout()
        self.layoutKeystrokeSounds.setObjectName("layoutKeystrokeSounds")
        self.checkBoxToggleSounds = QtWidgets.QCheckBox(self.scrollAreaWidgetContents)
        self.checkBoxToggleSounds.setText("")
        self.checkBoxToggleSounds.setObjectName("checkBoxToggleSounds")
        self.layoutKeystrokeSounds.addWidget(self.checkBoxToggleSounds)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.layoutKeystrokeSounds.addItem(spacerItem2)
        self.gridLayout.addLayout(self.layoutKeystrokeSounds, 3, 4, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem3, 4, 0, 1, 1)
        self.labelDarkMode = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        font = QtGui.QFont()
        font.setPointSize(24)
        self.labelDarkMode.setFont(font)
        self.labelDarkMode.setObjectName("labelDarkMode")
        self.gridLayout.addWidget(self.labelDarkMode, 1, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.comboSelectSound = QtWidgets.QComboBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboSelectSound.sizePolicy().hasHeightForWidth())
        self.comboSelectSound.setSizePolicy(sizePolicy)
        self.comboSelectSound.setMinimumSize(QtCore.QSize(230, 40))
        self.comboSelectSound.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.comboSelectSound.setObjectName("comboSelectSound")
        self.horizontalLayout_2.addWidget(self.comboSelectSound)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem4)
        self.gridLayout.addLayout(self.horizontalLayout_2, 5, 4, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem5, 0, 0, 1, 1)
        self.layoutDarkMode = QtWidgets.QHBoxLayout()
        self.layoutDarkMode.setObjectName("layoutDarkMode")
        self.checkBoxDarkMode = QtWidgets.QCheckBox(self.scrollAreaWidgetContents)
        font = QtGui.QFont()
        font.setPointSize(24)
        self.checkBoxDarkMode.setFont(font)
        self.checkBoxDarkMode.setText("")
        self.checkBoxDarkMode.setChecked(True)
        self.checkBoxDarkMode.setAutoExclusive(True)
        self.checkBoxDarkMode.setObjectName("checkBoxDarkMode")
        self.layoutDarkMode.addWidget(self.checkBoxDarkMode)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.layoutDarkMode.addItem(spacerItem6)
        self.gridLayout.addLayout(self.layoutDarkMode, 1, 4, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem7, 1, 3, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(10, 30, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.gridLayout.addItem(spacerItem8, 6, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        font = QtGui.QFont()
        font.setPointSize(24)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 5, 0, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem9, 9, 0, 1, 1)
        self.horizontalLayout_3.addLayout(self.gridLayout)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem10)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.horizontalLayout_5.addWidget(self.scrollArea)

        self.retranslateUi(settingsWindow)
        QtCore.QMetaObject.connectSlotsByName(settingsWindow)

    def retranslateUi(self, settingsWindow):
        _translate = QtCore.QCoreApplication.translate
        settingsWindow.setWindowTitle(_translate("settingsWindow", "Settings"))
        self.labelKeystrokeSounds.setText(_translate("settingsWindow", "Sound Effects"))
        self.buttonMainMenu.setText(_translate("settingsWindow", "Back"))
        self.buttonApply.setText(_translate("settingsWindow", "Apply"))
        self.labelDarkMode.setText(_translate("settingsWindow", "Dark Theme"))
        self.label.setText(_translate("settingsWindow", "Keystroke"))
